package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;

public class OriginatorInfo extends ASN1Encodable {
   private ASN1Set certs;
   private ASN1Set crls;

   public OriginatorInfo(ASN1Set certs, ASN1Set crls) {
      this.certs = certs;
      this.crls = crls;
   }

   public OriginatorInfo(ASN1Sequence seq) {
      int var2;
      if ((var2 = seq.size()) != 0) {
         if (var2 != 1) {
            if (var2 != 2) {
               throw new IllegalArgumentException("OriginatorInfo too big");
            }

            this.certs = ASN1Set.getInstance((ASN1TaggedObject)seq.getObjectAt(0), false);
            this.crls = ASN1Set.getInstance((ASN1TaggedObject)seq.getObjectAt(1), false);
         } else {
            ASN1TaggedObject seq1;
            if ((var2 = (seq1 = (ASN1TaggedObject)seq.getObjectAt(0)).getTagNo()) != 0) {
               if (var2 != 1) {
                  throw new IllegalArgumentException("Bad tag in OriginatorInfo: " + seq1.getTagNo());
               }

               this.crls = ASN1Set.getInstance(seq1, false);
            } else {
               this.certs = ASN1Set.getInstance(seq1, false);
            }
         }
      }

   }

   public static OriginatorInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static OriginatorInfo getInstance(Object obj) {
      if (obj != null && !(obj instanceof OriginatorInfo)) {
         if (obj instanceof ASN1Sequence) {
            return new OriginatorInfo((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid OriginatorInfo: " + obj.getClass().getName());
         }
      } else {
         return (OriginatorInfo)obj;
      }
   }

   public ASN1Set getCertificates() {
      return this.certs;
   }

   public ASN1Set getCRLs() {
      return this.crls;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      ASN1Set var2;
      if ((var2 = this.certs) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(false, 0, var2);
         var1.add(var3);
      }

      ASN1Set var4;
      if ((var4 = this.crls) != null) {
         DERTaggedObject var5;
         var5 = new DERTaggedObject.<init>(false, 1, var4);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }
}
